@@ -137,12 +137,12 @@
 #' [Analyse_SAR.OSLdata], which works with
 #' [Risoe.BINfileData-class] objects.
 #'
-#' **The function currently does only support 'OSL' or 'IRSL' data!**
+#' **The function currently does support only 'OSL', 'IRSL' and 'POSL' data!**
 #'
-#' @section Function version: 0.8.6
+#' @section Function version: 0.8.8
 #'
 #' @author
-#' Sebastian Kreutzer, IRAMAT-CRP2A, UMR 5060, Université Bordeaux Montaigne (France)
+#' Sebastian Kreutzer, IRAMAT-CRP2A, UMR 5060, CNRS-Université Bordeaux Montaigne (France)
 #'
 #'
 #' @seealso [calc_OSLLxTxRatio], [plot_GrowthCurve], [RLum.Analysis-class],
@@ -401,28 +401,28 @@ if(is.list(object)){
     ##INTEGRAL LIMITS
     if(!is(signal.integral, "integer") | !is(background.integral, "integer")){
       stop("[analyse_SAR.CWOSL()] 'signal.integral' or 'background.integral' is not
-           of type integer!")
+           of type integer!",  call. = FALSE)
     }
 
 
 
-      ##CHECK IF DATA SET CONTAINS ANY OSL curve
-      if (!any(grepl("OSL", structure_RLum(object)$recordType)) &&
-          !any(grepl("IRSL", structure_RLum(object)$recordType))) {
-        warning(
-          "[analyse_SAR.CWOSL()] No record of type 'OSL' or 'IRSL' are detected in the sequence object! NULL returned.",
-          call. = FALSE
-        )
-
+    ##CHECK IF DATA SET CONTAINS ANY OSL or IRSL curve
+    if (!any(c(grepl("OSL", names(object), fixed = TRUE), grepl("IRSL", names(object), fixed = TRUE)))){
+        stop("[analyse_SAR.CWOSL()] No record of type 'OSL', 'IRSL', 'POSL' detected! NULL returned.",
+             call. = FALSE)
         return(NULL)
 
-      }
+    }
 
-    ##Check if any OSL curve is measured, if not set curve type on IRSL
-    ##to allow further proceedings
-    CWcurve.type  <- ifelse(!TRUE%in%grepl("OSL", structure_RLum(object)$recordType),
-                            "IRSL","OSL")
+    ## try to extract the correct curves for the sequence based on allowed curve types and
+    ## the curve type used most frequently
+      ## now remove all non-allowed curves
+      CWcurve.type <-
+        regmatches(names(object),
+                   m = regexpr("(OSL|IRSL|POSL)(?!\\))", names(object), perl = TRUE))
 
+      ## now get the type which is used most
+      CWcurve.type <- names(which.max(table(CWcurve.type)))
 
 # Rejection criteria ------------------------------------------------------
 
