@@ -10,18 +10,21 @@ temp_analysis <- set_RLum("RLum.Analysis", records = temp_list)
 test_that("standard check", {
   testthat::skip_on_cran()
 
-  ##trgger errors
+  ##trigger errors
   expect_null(fit_OSLLifeTimes(object = "test"))
 
   ## Test different inputs
   ##simple run
+  set.seed(1)
   expect_s4_class(object = fit_OSLLifeTimes(
     object = ExampleData.TR_OSL,
+    plot = FALSE,
     n.components = 1), class = "RLum.Results")
 
   ##simple list
   expect_s4_class(object = fit_OSLLifeTimes(
     object = temp_list,
+    plot = FALSE,
     n.components = 1), class = "RLum.Results")
 
   ##simple RLum.Analysis
@@ -36,6 +39,7 @@ test_that("standard check", {
   expect_s4_class(object = fit_OSLLifeTimes(
     object = ExampleData.TR_OSL,
     method_control = list(seed = 1, weights = FALSE),
+    plot = FALSE,
     n.components = 1), class = "RLum.Results")
 
   ##test options
